@@ -568,7 +568,7 @@ sjp.glm.slope <- function(fit, title, geom.size, geom.colors, remove.estimates,
       # melt variable
       mydf.vals <- data.frame(values = vals.unique)
       # convert factor to numeric
-      if (is.factor(mydf.vals$values)) mydf.vals$values <- sjmisc::to_value(mydf.vals$values, 0, keep.labels = F)
+      if (is.factor(mydf.vals$values)) mydf.vals$values <- sjmisc::to_value(mydf.vals$values, start.at = 0, keep.labels = F)
       # check if we have a factor, then we may have reference levels
       if (is.factor(values)) {
         # add reference level to coefficient name
@@ -638,7 +638,7 @@ sjp.glm.slope <- function(fit, title, geom.size, geom.colors, remove.estimates,
         y.limits <- ylim
       }
       # create single plots for each numeric predictor
-      mp <- ggplot(mydf.metricpred[[i]], aes(x = values, y = y)) +
+      mp <- ggplot(mydf.metricpred[[i]], aes_string(x = "values", y = "y")) +
         labs(x = axisLabels.mp[i], y = y.title, title = title)
       # special handling for negativ binomial
       if (sjmisc::str_contains(fitfam$family, "negative binomial", ignore.case = T)) {
@@ -672,7 +672,7 @@ sjp.glm.slope <- function(fit, title, geom.size, geom.colors, remove.estimates,
       } else {
         y.limits <- ylim
       }
-      mp <- ggplot(mydf.ges, aes(x = values, y = y)) +
+      mp <- ggplot(mydf.ges, aes_string(x = "values", y = "y")) +
         labs(x = NULL, y = y.title, title = title)
       # special handling for negativ binomial
       if (sjmisc::str_contains(fitfam$family, "negative binomial", ignore.case = T)) {
